@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::JSUrlFor;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use Mojo::ByteStream qw/b/;
 use Data::Dumper;
@@ -95,10 +95,10 @@ sub _collect_endpoint_routes {
 sub _get_path_for_route {
     my ( $self, $parent ) = @_;
 
-    my $path = $parent->pattern->pattern // '';
+    my $path = $parent->pattern->unparsed // '';
 
     while ( $parent = $parent->parent ) {
-        $path = ($parent->pattern->pattern//'') . $path;
+        $path = ($parent->pattern->unparsed//'') . $path;
     }
 
     return $path;
